==> tine20-allinone_2017.08.11.tar.bz2: Filemanager/js/Filemanager-lang-de-debug.js <==
/********************** tine translations of Filemanager**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Filemanager'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-01-04 10:29+0100\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 2.0.5\n"

, "Row double click default"
: "Zeilen Doppelklick Standard"

, "Defines which action should be executed on double click by default?"
: "Legt fest, welche Aktion bei einem Doppelklick standardmäßig ausgeführt werden soll."

, "Name"
: "Name"

, "Size"
: "Größe"

, "Contenttype"
: "Typ"

, "Folder, Folders"
: [
  "Ordner"
 ,"Ordner"

]
, "path"
: "Pfad"

, "Url"
: "URL"

, "Password"
: "Passwort"

, "Valid until"
: "Gültig bis"

, "Send as e-mail"
: "Sende als E-Mail"

, "Download"
: "Herunterladen"

, "Create Public Link"
: "Öffentlichen Link erstellen"

, "Remove record"
: "Eintrag entfernen"

, "Creating new Download Link..."
: "Erstelle neuen Download Link..."

, "Deleting Download Links..."
: "Lösche Download Links..."

, "Deleting Download Link..."
: "Lösche Download Link..."

, "Created By"
: "Erstellt von"

, "Creation Time"
: "Erstellt am"

, "Expiration Time"
: "Fristablauf"

, "Access Count"
: "Anzahl der Zugriffe"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Revision"
: "Version"

, "This folder has own revision settings"
: "Dieser Ordner hat eigene Revisions Einstellungen"

, "Revision active"
: "Revision aktiv"

, "Limit revision amount to"
: "Revisionen limitieren auf"

, "Hold-back in months"
: "Vorhalten in Monaten"

, "Upload Failed"
: "Hochladen fehlgeschlagen"

, "Putting files in this folder is not allowed!"
: "In diesem Ordner dürfen keine Dateien abgelegt werden!"

, "Tags"
: "Tags"

, "Revision Size"
: "Revisions Größe"

, "Total size of all available revisions"
: "Gesamtgröße der verfügbaren Revisionen"

, "Indexed"
: "Indiziert"

, "File contents is part of the search index"
: "Dateiinhalte sind Teil der indizierten Suche"

, "Upload"
: "Hochladen"

, "Folder Up"
: "Aufwärts"

, "Filemanager"
: "Dateimanager"

, "Save locally"
: "Lokal speichern"

, "Edit folder"
: "Ordner bearbeiten"

, "edit file"
: "Datei bearbeiten"

, "File, Files"
: [
  "Datei"
 ,"Dateien"

]
, "Public Links"
: "Öffentliche Links"

, "Type"
: "Typ"

, "Not yet indexed"
: "Noch nicht indiziert"

, "Modified By"
: "Zuletzt geändert von"

, "Last Modified"
: "Letzter Änderungszeitpunkt"

, "Description"
: "Beschreibung"

, "Enter description"
: "Beschreibung eingeben"

, "Select a file"
: "Wähle eine Datei"

, "Service Unavailable"
: "Dienst nicht verfügbar"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Der Dateimanager ist nicht korrekt konfiguriert. Bitte kontaktieren sie ihren Administrator oder ziehen sie die {0}Tine 2.0 Dokumentation{1} zu Rate."

, "Files already exists"
: "Datei(en) schon vorhanden"

, "Do you want to replace the following file(s)?"
: "Möchten Sie die folgenden Datei(en) ersetzen?"

, "Failure on create folder"
: "Fehler beim anlegen des Ordners"

, "Item with this name already exists!"
: "Item(s) mit diesem Namen schon vorhanden!"

, "Whole Filemanager"
: "Gesamter Dateimanager"

, "Search"
: "Suche"

, "This Folder"
: "Dieser Ordner"

, "Copying data .. {0}"
: "Kopiere Daten .. {0}"

, "Moving data .. {0}"
: "Verschiebe Daten .. {0}"

, "Please wait"
: "Bitte warten"

, "Quick Search"
: "Schnellsuche"

, "File Contents"
: "Dateiinhalt"

, "Download Link, Download Links"
: [
  "Download Link"
 ,"Download Links"

]
, "Node Download Links"
: "Knoten Download Links"

, "Close"
: "Schließen"

, "No preview available."
: "Keine Vorschau verfügbar."

, "Notifications"
: "Benachrichtigungen"

, "This folder has own notification settings"
: "Dieser Ordner hat eigene Benachrichtigungs Einstellungen"

, "Notification"
: "Benachrichtigung"

, "Notification active"
: "Benachrichtigung aktiv"

, "Summary"
: "Zusammenfassung"

, "Day"
: "Tag"

, "Days"
: "Tage"

, "Search for users ..."
: "Suche nach Benutzern ..."

, "No permission"
: "Keine Berechtigung"

, "all"
: "alle"

, "Search for groups ..."
: "Suche nach Gruppen ..."

, "Grants"
: "Berechtigungen"

, "This folder has own grants"
: "Dieser Ordner hat eigene Berechtigungen"

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: "Berechtigungen gelten ebenfalls rekursiv für alle Unterordner sofern diese nicht über eigene Berechtigungen verfügen."

, "This folder is pin protected"
: "Dieser Ordner ist PIN-geschützt"

, "If pin protection is enabled, users have to authenticate with their pin before they can access the folder contents."
: "Wenn PIN-Schutz aktiviert ist, müssen sich Benutzer  mit ihrem PIN authentifizieren, bevor Sie auf den Ordnerinhalt zugreifen können."

, "The grant to download files"
: "Das Recht Datein zu downloaden"

, "Publish"
: "Veröffentlichen"

, "The grant to create anonymous download links for files"
: "Das Recht anonyme Download Links für Datein zu erstellen"

, "Usage"
: "Verbrauch"

, "This folder has own quota"
: "Dieser Ordner hat ein eigenes Kontingent"

, "Quota"
: "Kontingent"

, "no quota set"
: "Kein Kontingent gesetzt"

, "Current Usage"
: "Aktuelle Nutzung"

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: "Das Kontingent gilt rekursiv für Dateien und Unter-Ordner. Achtung: Das effektive Kontingent kann abweichen wenn ein übergeordneter Ordner eine geringeres Kontingent gesetzt hat."

, "File Type"
: "Dateityp"

, "Usage by File Type"
: "Verbrauch nach Dateityp"

, "User"
: "Benutzer"

, "Usage by User"
: "Verbrauch nach Benutzer"

, "unknown"
: "unbekannt"

, "Create Folder"
: "Ordner anlegen"

, "New Folder"
: "Neuer Ordner"

, "Please enter the name of the new folder:"
: "Bitte geben Sie den Namen für den neuen Ordner ein:"

, "No {0} added"
: "Kein {0} hinzugefügt"

, "You have to supply a {0} name!"
: "Sie müssen einen {0}-namen angeben!"

, "Edit Properties"
: "Eigenschaften bearbeiten"

, "Rename"
: "Umbenennen"

, "Rename {0}"
: "{0} umbenennen"

, "Please enter the new name of the {0}:"
: "Bitte den neuen Namen von {0} eingeben:"

, "Not renamed {0}"
: "Unbenannter {0}"

, "System Link"
: "System Link"

, "Use this link to share the entry with other system users"
: "Verwende diesen Link um den Eintrag mit einem anderen Systembenutzer zu teilen"

, "Delete"
: "Löschen"

, "Do you really want to delete the following files?"
: "Möchten Sie folgende Datei(en) löschen?"

, "Move"
: "Verschieben"

, "Move Items"
: "Einträge verschieben"

, "Preview"
: "Vorschau"

, "Folder has been published successfully"
: "Ordner wurde erfolgreich veröffentlicht"

, "File has been published successfully"
: "Datei wurde erfolgreich veröffentlicht"

, "Reload),"
: ""

, "Public Download URL"
: "Öffentliche Download URL"

, "Serve anonymous downloads from a differnt URL. Make sure to setup propper rewrite rules."
: "Anonyme Downloads über eine andere URL ausliefern. Achtung: Sicherstellen, dass die Rewrite-Rules richtig gesetzt sind."

, "My folders"
: "Meine Ordner"

, "Shared folders"
: "Gemeinsame Ordner"

, "Other users folders"
: "Ordner anderer Benutzer"

, "Received"
: "Erhalten"

, "To"
: "An"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "From (E-Mail)"
: "Von (E-Mail)"

, "From (Name)"
: "Von (Name)"

, "Body"
: "Body"

, "Attachments"
: "Anhänge"

, "Destination is a Subfolder"
: "Ziel ist ein Unterordner"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "Das Ziel ist ein Unterordner. Es ist nicht erlaubt einen Ordner in einen seiner Unterordner zu kopieren oder zu verschieben."

, "Destination has the same Path"
: "Ziel hat den gleichen Pfad"

, "The destination has the same path the source has. No action has been performed."
: "Das Ziel hat den selben Pfad wie die Quelle. Die Aktion wurde nicht ausgeführt."

, "manage shared folders"
: "Gemeinsame Ordner verwalten"

, "Create new shared folders"
: "Neue gemeinsame Ordner anlegen und verwalten"

, "Manage anonymous download links"
: "Anonyme Download Links verwalten"

, "Allow to see, add and delete download links of files and folders"
: "Anzeigen, Hinzufügen und Löschen von Download Links erlauben"








, "Folder"
: "Ordner"

, "File"
: "Datei"

, "Download Link"
: "Download Link"

}));

==> tine20-allinone_2018.08.9.tar.bz2: Filemanager/js/Filemanager-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:18+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: de\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Upload Failed"
: "Hochladen fehlgeschlagen"

, "Putting files in this folder is not allowed!"
: "In diesem Ordner dürfen keine Dateien abgelegt werden!"

, "Filemanager"
: "Dateimanager"

, "Save locally"
: "Lokal speichern"

, "Tags"
: "Tags"

, "Name"
: "Name"

, "Size"
: "Größe"

, "Contenttype"
: "Typ"

, "Folder, Folders"
: [
  "Ordner"
 ,"Ordner"

]
, "Creation Time"
: "Erstellt am"

, "Created By"
: "Erstellt von"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Revision Size"
: "Revisions Größe"

, "Total size of all available revisions"
: "Gesamtgröße der verfügbaren Revisionen"

, "Indexed"
: "Indiziert"

, "File contents is part of the search index"
: "Dateiinhalte sind im Suchindex"

, "Upload"
: "Hochladen"

, "Open Data Safe"
: "Datentresor öffnen"

, "Folder Up"
: "Aufwärts"

, "Close Data Safe"
: "Datentresor schließen"

, "Node Download Links"
: "Knoten Download Links"

, "Url"
: "URL"

, "Password"
: "Passwort"

, "Valid until"
: "Gültig bis"

, "Send as e-mail"
: "Sende als E-Mail"

, "Download"
: "Herunterladen"

, "Service Unavailable"
: "Dienst nicht verfügbar"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Der Dateimanager ist nicht korrekt konfiguriert. Bitte kontaktieren sie ihren Administrator oder ziehen sie die {0}Tine 2.0 Dokumentation{1} zu Rate."

, "Files already exists"
: "Datei(en) schon vorhanden"

, "Do you want to replace the following file(s)?"
: "Möchten Sie die folgenden Datei(en) ersetzen?"

, "Failure on create folder"
: "Fehler beim anlegen des Ordners"

, "Item with this name already exists!"
: "Item(s) mit diesem Namen schon vorhanden!"

, "Revision"
: "Version"

, "This folder has own revision settings"
: "Dieser Ordner hat eigene Revisions Einstellungen"

, "Revision active"
: "Revision aktiv"

, "Limit revision amount to"
: "Revisionen limitieren auf"

, "Hold-back in months"
: "Vorhalten in Monaten"

, "path"
: "Pfad"

, "Notifications"
: "Benachrichtigungen"

, "This folder has own notification settings"
: "Dieser Ordner hat eigene Benachrichtigungs Einstellungen"

, "Reload"
: "Aktualisieren"

, "Create Folder"
: "Ordner anlegen"

, "New Folder"
: "Neuer Ordner"

, "Please enter the name of the new folder:"
: "Bitte geben Sie den Namen für den neuen Ordner ein:"

, "No {0} added"
: "Kein {0} hinzugefügt"

, "You have to supply a {0} name!"
: "Sie müssen einen {0}-namen angeben!"

, "Edit Properties"
: "Eigenschaften bearbeiten"

, "Rename"
: "Umbenennen"

, "Rename {0}"
: "{0} umbenennen"

, "Please enter the new name of the {0}:"
: "Bitte den neuen Namen von {0} eingeben:"

, "Not renamed {0}"
: "Unbenannter {0}"

, "System Link"
: "System Link"

, "Use this link to share the entry with other system users"
: "Verwende diesen Link um den Eintrag mit einem anderen Systembenutzer zu teilen"

, "Delete"
: "Löschen"

, "Do you really want to delete the following files?"
: "Möchten Sie folgende Datei(en) löschen?"

, "Move"
: "Verschieben"

, "Move Items"
: "Einträge verschieben"

, "Preview"
: "Vorschau"

, "Publish"
: "Veröffentlichen"

, "Public download links can be password protected. If left blank anyone who knows the link can download the selected files."
: "Anonyme Download Links können mit einem Passwort geschützt werden. Wenn kein Passwort angegeben ist kann jeder der den Link kennt auf die selektierten Dateien zugreifen."

, "Folder has been published successfully"
: "Ordner wurde erfolgreich veröffentlicht"

, "File has been published successfully"
: "Datei wurde erfolgreich veröffentlicht"

, "File, Files"
: [
  "Datei"
 ,"Dateien"

]
, "The grant to download files"
: "Das Recht Datein zu downloaden"

, "The grant to create anonymous download links for files"
: "Das Recht anonyme Download Links für Datein zu erstellen"

, "Copying data .. {0}"
: "Kopiere Daten .. {0}"

, "Moving data .. {0}"
: "Verschiebe Daten .. {0}"

, "Please wait"
: "Bitte warten"

, "Quick Search"
: "Schnellsuche"

, "Type"
: "Typ"

, "Description"
: "Beschreibung"

, "File Contents"
: "Dateiinhalt"

, "Download Link, Download Links"
: [
  "Download Link"
 ,"Download Links"

]
, "Grants"
: "Berechtigungen"

, "This folder has own grants"
: "Diese Ordner hat eigene Berechtigungen"

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: "Berechtigungen gelten ebenfalls rekursiv für alle Unterordner sofern diese nicht über eigene Berechtigungen verfügen."

, "This folder is part of the data safe"
: "Dieser Ordner ist Teil des Datentresors"

, "If data safe protection is enabled, this folder and all it's contents is only shown if the data safe is opened."
: "Wenn der Datentresor Schutz aktiviert ist, kann auf diesen Ordner und seine Inhalte nur zugegriffen werden wenn der Datentresor geöffnet ist."

, "Sorry, Tine 2.0 would like to show you the contents of the file displayed."
: "Schade, gerne hätte Tine 2.0 Ihnen jetzt den Inhalt der Datei angezeigt."

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: "Das geht z.B. für .doc, .jpg, .pdf und noch für weitere Dateiformate."

, "Interested? Then let us know!"
: "Interessiert? Dann melden Sie sich bei uns!"

, "We are happy make you a non-binding offer."
: "Wir machen Ihnen gerne ein unverbindliches Angebot."

, "No preview available."
: "Keine Vorschau verfügbar."

, "Notification"
: "Benachrichtigung"

, "Notification active"
: "Benachrichtigung aktiv"

, "Summary"
: "Zusammenfassung"

, "Once a Day, Every {0} Days"
: [
  "Einmal am Tag"
 ,"Alle {0} Tage"

]
, "No"
: "Nein"

, "Don't summarize"
: "Nicht zusammenfassen"

, "Once a day"
: "Einmal täglich"

, "Every 3 days"
: "Alle 3 Tage"

, "Once a week"
: "Einmal die Woche"

, "Once a month"
: "Einmal pro Monat"

, "Once a year"
: "Einmal pro Jahr"

, "Search for users ..."
: "Suche nach Benutzern ..."

, "No permission"
: "Keine Berechtigung"

, "all"
: "alle"

, "Remove record"
: "Eintrag entfernen"

, "Search for groups ..."
: "Suche nach Gruppen ..."

, "Close"
: "Schliessen"

, "Loading preview ..."
: ""

, "Edit folder"
: "Ordner bearbeiten"

, "edit file"
: "Datei bearbeiten"

, "Public Links"
: "Öffentliche Links"

, "Not yet indexed"
: "Noch nicht indiziert"

, "Modified By"
: "Zuletzt geändert von"

, "Last Modified"
: "Letzter Änderungszeitpunkt"

, "Enter description"
: "Beschreibung eingeben"

, "Select a file"
: "Wähle eine Datei"

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Create Public Link"
: "Öffentlichen Link erstellen"

, "Creating new Download Link..."
: "Erstelle neuen Download Link..."

, "Deleting Download Links..."
: "Lösche Download Links..."

, "Deleting Download Link..."
: "Lösche Download Link..."

, "Expiration Time"
: "Fristablauf"

, "Access Count"
: "Anzahl der Zugriffe"

, "Usage"
: "Verbrauch"

, "This folder has own quota"
: "Dieser Ordner hat ein eigenes Kontingent"

, "Quota"
: "Kontingent"

, "no quota set"
: "Kein Kontingent gesetzt"

, "Current Usage"
: "Aktuelle Nutzung"

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: "Das Kontingent gilt rekursiv für Dateien und Unter-Ordner. Achtung: Das effektive Kontingent kann abweichen wenn ein übergeordneter Ordner eine geringeres Kontingent gesetzt hat."

, "File Type"
: "Dateityp"

, "Usage by File Type"
: "Verbrauch nach Dateityp"

, "User"
: "Benutzer"

, "Usage by User"
: "Verbrauch nach Benutzer"

, "unknown"
: "unbekannt"

, "Whole Filemanager"
: "Gesamter Dateimanager"

, "This Folder"
: "Dieser Ordner"

, "Search"
: "Suche"

, "Row double click default"
: "Standardverhalten bei Doppelklick auf Zeile"

, "Defines which action should be executed on double click by default?"
: "Legt fest, welche Aktion bei einem Doppelklick standardmäßig ausgeführt werden soll."

, "Password for download required"
: "Zum Herunterladen Passwort eingeben"

, "Submit"
: "Abschicken"

, "File not found!"
: "Datei nicht gefunden!"

, "Public Download URL"
: "Öffentliche Download URL"

, "Serve anonymous downloads from a different URL. Make sure to setup proper rewrite rules."
: "Anonyme Downloads von einer anderen URL ausliefern. Stellen sie sicher dass die rewrite Regeln entsprechend angepasst sind."

, "manage shared folders"
: "Gemeinsame Ordner verwalten"

, "Create new shared folders"
: "Neue gemeinsame Ordner anlegen und verwalten"

, "Manage anonymous download links"
: "Anonyme Download Links verwalten"

, "Allow to see, add and delete download links of files and folders"
: "Anzeigen, Hinzufügen und Löschen von Download Links erlauben"

, "Destination is a Subfolder"
: "Ziel ist ein Unterordner"

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: "Das Ziel ist ein Unterordner. Es ist nicht erlaubt einen Ordner in einen seiner Unterordner zu kopieren oder zu verschieben."

, "Destination has the same Path"
: "Ziel hat den gleichen Pfad"

, "The destination has the same path the source has. No action has been performed."
: "Das Ziel hat den selben Pfad wie die Quelle. Die Aktion wurde nicht ausgeführt."

, "My folders"
: "Meine Ordner"

, "Shared folders"
: "Gemeinsame Ordner"

, "Other users folders"
: "Ordner anderer Benutzer"

, "Received"
: "Erhalten"

, "To"
: "An"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "From (E-Mail)"
: "Von (E-Mail)"

, "From (Name)"
: "Von (Name)"

, "Body"
: "Inhalt"

, "Attachments"
: "Anhänge"

, "Folder"
: "Ordner"

, "File"
: "Datei"

, "Download Link"
: "Download Link"

, "Once a Day"
: "Einmal am Tag"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
